@@ -1,5 +1,5 @@
 
-#include <glib.h>
+#include <glibmm.h>
 
 // Disable the 'const' function attribute of the get_type() functions.
 // GCC would optimize them out because we don't use the return value.
@@ -42,9 +42,9 @@
 #include "serveroperation.h"
 #include "serverprovider.h"
 #include "set.h"
+#include "sqlbuilder.h"
 #include "sqlexpr.h"
 #include "sqlparser.h"
-#include "sqlbuilder.h"
 #include "sqlstatement.h"
 #include "statement.h"
 #include "transactionstatus.h"
